==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Praca</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Życie</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Inne</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Dzień przed rozpoczęciem</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Przypomnij mi jutro</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Przypomnij mi później</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minut później</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 godzinę później</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 godziny później</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Jutro</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Zaplanuj przypomnienie</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 do %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dzisiaj</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Dzień przed startem</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Zamknij</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Przypomnij mi jutro</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Przypomnij mi później</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Zaplanuj przypomnienie</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 do %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Dzisiaj</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Jutro</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Praca</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Życie</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Inne</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Dzień przed rozpoczęciem</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Przypomnij mi jutro</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Przypomnij mi później</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 minut później</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 godzinę później</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 godziny później</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Jutro</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Zaplanuj przypomnienie</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 do %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dzisiaj</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
